package com.chelvc.cloud.admin.controller;

import com.chelvc.cloud.vehicle.api.dto.UserCouponDTO;
import com.chelvc.cloud.vehicle.api.param.UserCouponPagingParam;
import com.chelvc.cloud.vehicle.api.service.UserCouponService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.common.model.Pagination;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

/**
 * 用户优惠券接口
 *
 * @author qizai
 * @Date 2023/11/16
 **/
@Validated
@RestController
@ResponseWrapping
@PreAuthorize("isScope('EMPLOYEE')")
public class UserCouponController {
    @DubboReference
    private UserCouponService userCouponService;

    /**
     * 分页查询用户领取优惠券详情
     *
     * @param param 查询参数
     * @return 用户领取优惠券分页信息
     */
    @GetMapping("/usercoupon/paging")
    public Pagination<UserCouponDTO> getUserCouponPaging(@Valid UserCouponPagingParam param) {
        return this.userCouponService.getCouponClaimPaging(param);
    }
}
